Skip to contents

A standalone helper for computing Carlson TSI directly from observed water quality measurements, without running the full prediction pipeline. Useful for computing observed trophic state from grab sample data for comparison against modelled predictions.

Usage

ok_tsi_observed(tp_ugl = NULL, chla_ugl = NULL, secchi_m = NULL)

Arguments

tp_ugl

Numeric. Observed in-lake total phosphorus (ug/L). Optional.

chla_ugl

Numeric. Observed chlorophyll-a (ug/L). Optional.

secchi_m

Numeric. Observed Secchi depth (m). Optional.

Value

A named list with elements tsi_tp, tsi_chla, tsi_secchi, tsi_n, tsi_mean, and trophic_state.

References

Carlson, R.E. (1977). A trophic state index for lakes. Limnology and Oceanography, 22(2), 361-369.

Examples

ok_tsi_observed(tp_ugl = 85, chla_ugl = 22, secchi_m = 0.8)
#> $tsi_tp
#> [1] 68.21303
#> 
#> $tsi_chla
#> [1] 60.92313
#> 
#> $tsi_secchi
#> [1] 63.2155
#> 
#> $tsi_n
#> [1] 3
#> 
#> $tsi_mean
#> [1] 64.11722
#> 
#> $trophic_state
#> [1] "Eutrophic"
#>